@@ -23,11 +23,11 @@ Artifactory::Client - Perl client for Artifactory REST API
 
 =head1 VERSION
 
-Version 0.9.0
+Version 0.9.1
 
 =cut
 
-our $VERSION = 'v0.9.0';
+our $VERSION = 'v0.9.1';
 
 =head1 SYNOPSIS
 
@@ -37,12 +37,16 @@ method provided in this module returns a HTTP::Response object.
 
     use Artifactory::Client;
 
+    my $h = HTTP::Headers->new();
+    $h->authorization_basic( 'admin', 'password' );
+    my $ua = LWP::UserAgent->new( default_headers => $h );
+
     my $args = {
-        artifactory => 'http://artifactory.server.com',
-        port => 8080,
-        repository => 'myrepository',
+        artifactory  => 'http://artifactory.server.com',
+        port         => 8080,
+        repository   => 'myrepository',
         context_root => '/', # Context root for artifactory. Defaults to 'artifactory'.
-        ua => LWP::UserAgent->new() # LWP::UserAgent-like object is pluggable.  Default is LWP::UserAgent.
+        ua           => $ua  # Dropping in custom UA with default_headers set.  Default is a plain LWP::UserAgent.
     };
 
     my $client = Artifactory::Client->new( $args );
@@ -63,10 +67,6 @@ method provided in this module returns a HTTP::Response object.
     # Custom requests can also be made via usual get / post / put / delete requests.
     my $resp = $client->get( 'http://artifactory.server.com/path/to/resource' );
 
-    # drop in a different UserAgent:
-    my $ua = WWW::Mechanize->new();
-    $client->ua( $ua ); # now uses WWW::Mechanize to make requests
-
 Note on testing: This module is developed using Test-Driven Development.  I
 have functional tests making real API calls, however they contain proprietary
 information and I am not allowed to open source them.  The unit tests included
@@ -1273,9 +1273,10 @@ Returns a list of effective permissions for the specified item (file or folder)
 =cut
 
 sub effective_item_permissions {
-    my ( $self, $path ) = @_;
-    $path = $self->_merge_repo_and_path($path);
-    my $url = $self->_api_url() . "/storage/$path";
+    my ( $self, $arg ) = @_;
+
+    my $path = $self->_merge_repo_and_path($arg);
+    my $url  = $self->_api_url() . "/storage/$path?permissions";
     return $self->get($url);
 }
 
@@ -1316,15 +1317,16 @@ sub deactivate_master_key_encryption {
     return $self->post($url);
 }
 
-=head2 set_gpg_public_key
+=head2 set_gpg_public_key( key => $string )
 
 Sets the public key that Artifactory provides to Debian clients to verify packages
 
 =cut
 
 sub set_gpg_public_key {
-    my $self = shift;
-    return $self->_handle_gpg_key( 'public', 'put' );
+    my ( $self, %args ) = @_;
+    my $key = $args{key};
+    return $self->_handle_gpg_key( 'public', 'put', content => $key );
 }
 
 =head2 get_gpg_public_key
@@ -1338,15 +1340,16 @@ sub get_gpg_public_key {
     return $self->_handle_gpg_key( 'public', 'get' );
 }
 
-=head2 set_gpg_private_key
+=head2 set_gpg_private_key( key => $string )
 
 Sets the private key that Artifactory will use to sign Debian packages
 
 =cut
 
 sub set_gpg_private_key {
-    my $self = shift;
-    return $self->_handle_gpg_key( 'private', 'put' );
+    my ( $self, %args ) = @_;
+    my $key = $args{key};
+    return $self->_handle_gpg_key( 'private', 'put', content => $key );
 }
 
 =head2 set_gpg_pass_phrase( $passphrase )
@@ -1357,8 +1360,7 @@ Sets the pass phrase required signing Debian packages using the private key
 
 sub set_gpg_pass_phrase {
     my ( $self, $pass ) = @_;
-    my %header = ( 'X-GPG-PASSPHRASE' => $pass );
-    return $self->_handle_gpg_key( 'passphrase', 'put', %header );
+    return $self->_handle_gpg_key( 'passphrase', 'put', 'X-GPG-PASSPHRASE' => $pass );
 }
 
 =head1 REPOSITORIES
@@ -1476,6 +1478,19 @@ sub calculate_npm_repository_metadata {
     return $self->_handle_repository_reindex("/npm/$repository/reindex");
 }
 
+=head2 calculate_bower_repository_metadata
+
+Recalculates the bower search index for this repository (local/virtual). Please see the Bower integration documentation for
+more details.
+
+=cut
+
+sub calculate_bower_repository_metadata {
+    my $self       = shift;
+    my $repository = $self->repository();
+    return $self->_handle_repository_reindex("/bower/$repository/reindex");
+}
+
 =head2 calculate_maven_index( repos => [ 'repo1', 'repo2' ], force => 0/1 )
 
 Calculates/caches a Maven index for the specified repositories
@@ -1571,6 +1586,22 @@ sub save_general_configuration {
     );
 }
 
+=head2 update_custom_url_base( $url )
+
+Changes the Custom URL base
+
+=cut
+
+sub update_custom_url_base {
+    my ( $self, $base ) = @_;
+    my $url = $self->_api_url() . '/system/configuration/baseUrl';
+    return $self->put(
+        $url,
+        'Content-Type' => 'text/plain',
+        content        => $base
+    );
+}
+
 =head2 license_information
 
 Retrieve information about the currently installed license
@@ -1621,8 +1652,7 @@ sub version_and_addons_information {
 
 =head2 execute_plugin_code( $execution_name, $params, $async )
 
-Executes a named execution closure found in the executions section of a user
-plugin
+Executes a named execution closure found in the executions section of a user plugin
 
 =cut
 
